# dsaria

**A simple Python library for data structures and algorithms.**

`dsaria` is a lightweight Python package that I've created to understand data structures and algorithms, and to learn
how to package python projects.

---

## Installation

Install directly from PyPI:

```bash
pip install dsaria
```

## Current Features
### Sorting Algorithms
- Bubble Sort
- Counting Sort
- More sorting algorithms coming soon!
### Data Structures
- Coming soon!